@@ -11,7 +11,13 @@ from numpy import unique
 from natsort import natsorted
 
 from . import geometries
-from .utils import _set_attrs_on_all_vars, _separate_metadata, _check_filetype, _is_path
+from .utils import (
+    _set_attrs_on_all_vars,
+    _separate_metadata,
+    _check_filetype,
+    _is_path,
+    _is_dir,
+)
 
 
 _BOUT_PER_PROC_VARIABLES = [
@@ -29,6 +35,17 @@ _BOUT_PER_PROC_VARIABLES = [
     "MYPE",
 ]
 _BOUT_TIME_DEPENDENT_META_VARS = ["iteration", "hist_hi", "tt"]
+_BOUT_GEOMETRY_VARS = [
+    "ixseps1",
+    "ixseps2",
+    "jyseps1_1",
+    "jyseps2_1",
+    "jyseps1_2",
+    "jyseps2_2",
+    "nx",
+    "ny",
+    "ny_inner",
+]
 
 
 # This code should run whenever any function from this module is imported
@@ -60,6 +77,7 @@ def open_boutdataset(
     inputfilepath=None,
     geometry=None,
     gridfilepath=None,
+    grid_mismatch="raise",  #: Union[Literal["raise"], Literal["warn"], Literal["ignore"]]
     chunks=None,
     keep_xboundaries=True,
     keep_yboundaries=False,
@@ -121,6 +139,12 @@ def open_boutdataset(
     gridfilepath : str, optional
         The path to a grid file, containing any variables needed to apply the geometry
         specified by the 'geometry' option, which are not contained in the dump files.
+        This may either be the path of the grid file itself, or the directory
+        relative to which the grid from the settings file can be found.
+    grid_mismatch : str, optional
+        How to handle if the grid is not the grid that has been used for the
+        simulation. Can be "raise" to raise a RuntimeError, "warn" to raise a
+        warning, or ignore to ignore the mismatch silently.
     keep_xboundaries : bool, optional
         If true, keep x-direction boundary cells (the cells past the physical
         edges of the grid, where boundary conditions are set); increases the
@@ -302,6 +326,13 @@ def open_boutdataset(
         if info:
             print("Applying {} geometry conventions".format(geometry))
 
+        if _is_dir(gridfilepath):
+            if "grid" in ds.options:
+                gridfilepath += "/" + ds.options["grid"]
+            else:
+                warn(
+                    "gridfilepath set to a directory, but no grid used in simulation. Continuing without grid."
+                )
         if gridfilepath is not None:
             grid = _open_grid(
                 gridfilepath,
@@ -317,6 +348,23 @@ def open_boutdataset(
         if info:
             warn("No geometry type found, no physical coordinates will be added")
 
+    if grid:
+        grididoptions = ds.metadata.get("grid_id", None)
+        grididfile = grid.get("grid_id", None)
+        if grididoptions and grididfile and grididfile != grididoptions:
+            msg = f"""The grid used for the simulation is not the one used.
+For the simulation {grididoptions} was used,
+but we did load {grididfile}."""
+            if grid_mismatch == "warn":
+                warn(msg)
+            elif grid_mismatch == "ignore":
+                pass
+            else:
+                raise ValueError(msg)
+        for v in _BOUT_GEOMETRY_VARS:
+            if v not in ds.metadata and v in grid:
+                ds.metadata[v] = grid[v].values
+
     # Update coordinates to match particular geometry of grid
     ds = geometries.apply_geometry(ds, geometry, grid=grid)
 
@@ -332,6 +380,42 @@ def open_boutdataset(
     # BOUT++
     ds.bout.fine_interpolation_factor = 8
 
+    if ("dump" in input_type or "restart" in input_type) and ds.metadata[
+        "BOUT_VERSION"
+    ] < 4.0:
+        # Add workarounds for missing information or different conventions in data saved
+        # by BOUT++ v3.x.
+        for v in ds:
+            if ds.metadata["bout_zdim"] in ds[v].dims:
+                # All fields saved on aligned grid for BOUT-3
+                ds[v].attrs["direction_y"] = "Aligned"
+
+            added_location = False
+            if any(
+                d in ds[v].dims
+                for d in (
+                    ds.metadata["bout_xdim"],
+                    ds.metadata["bout_ydim"],
+                    ds.metadata["bout_zdim"],
+                )
+            ):
+                # zShift, etc. did not support staggered grids in BOUT++ v3 anyway, so
+                # just treat all variables as if they were at CELL_CENTRE
+                ds[v].attrs["cell_location"] = "CELL_CENTRE"
+                added_location = True
+            if added_location:
+                warn(
+                    "Detected data from BOUT++ v3.x. Treating all variables as being "
+                    "at `CELL_CENTRE`. Should be similar to what BOUT++ v3.x did, but "
+                    "if your code uses staggered grids, this may produce unexpected "
+                    "effects in some places."
+                )
+
+        if "nz" not in ds.metadata:
+            # `nz` used to be stored as `MZ` and `MZ` used to include an extra buffer
+            # point that was not used for data.
+            ds.metadata["nz"] = ds.metadata["MZ"] - 1
+
     if info == "terse":
         print("Read in dataset from {}".format(str(Path(datapath))))
     elif info:
@@ -567,17 +651,40 @@ def _auto_open_mfboutdataset(
 
         paths_grid, concat_dims = _arrange_for_concatenation(filepaths, nxpe, nype)
 
-        ds = xr.open_mfdataset(
-            paths_grid,
-            concat_dim=concat_dims,
-            combine="nested",
-            data_vars=data_vars,
-            preprocess=_preprocess,
-            engine=filetype,
-            chunks=chunks,
-            join="exact",
-            **kwargs,
-        )
+        try:
+            ds = xr.open_mfdataset(
+                paths_grid,
+                concat_dim=concat_dims,
+                combine="nested",
+                data_vars=data_vars,
+                preprocess=_preprocess,
+                engine=filetype,
+                chunks=chunks,
+                join="exact",
+                **kwargs,
+            )
+        except ValueError as e:
+            message_to_catch = (
+                "some variables in data_vars are not data variables on the first "
+                "dataset:"
+            )
+            if str(e)[: len(message_to_catch)] == message_to_catch:
+                # Open concatenating any variables that are different in
+                # different files as a work around to support opening older
+                # data.
+                ds = xr.open_mfdataset(
+                    paths_grid,
+                    concat_dim=concat_dims,
+                    combine="nested",
+                    data_vars="different",
+                    preprocess=_preprocess,
+                    engine=filetype,
+                    chunks=chunks,
+                    join="exact",
+                    **kwargs,
+                )
+            else:
+                raise
     else:
         # datapath was nested list of Datasets
 
@@ -711,8 +818,16 @@ def _read_splitting(filepath, info, keep_yboundaries):
 
     # Check whether this is a single file squashed from the multiple output files of a
     # parallel run (i.e. NXPE*NYPE > 1 even though there is only a single file to read).
-    nx = ds["nx"].values
-    ny = ds["ny"].values
+    if "nx" in ds:
+        nx = ds["nx"].values
+    else:
+        # Workaround for older data files
+        nx = ds["MXSUB"].values * ds["NXPE"].values + 2 * ds["MXG"].values
+    if "ny" in ds:
+        ny = ds["ny"].values
+    else:
+        # Workaround for older data files
+        ny = ds["MYSUB"].values * ds["NYPE"].values
     nx_file = ds.dims["x"]
     ny_file = ds.dims["y"]
     is_squashed_doublenull = False
@@ -725,7 +840,10 @@ def _read_splitting(filepath, info, keep_yboundaries):
                 mxg = 0
 
             # Check if there are two divertor targets present
-            if ds["jyseps1_2"] > ds["jyseps2_1"]:
+            # Note: if jyseps2_1 and jyseps1_2 are not in ds it probably
+            # indicates older data and likely the upper target boundary cells
+            # were not saved anyway, so continue as if they were not.
+            if "jyseps2_1" in ds and ds["jyseps1_2"] > ds["jyseps2_1"]:
                 upper_target_cells = myg
             else:
                 upper_target_cells = 0
@@ -738,7 +856,13 @@ def _read_splitting(filepath, info, keep_yboundaries):
 
                 nxpe = 1
                 nype = 1
-                is_squashed_doublenull = (ds["jyseps2_1"] != ds["jyseps1_2"]).values
+                if "jyseps2_1" in ds:
+                    is_squashed_doublenull = (ds["jyseps2_1"] != ds["jyseps1_2"]).values
+                else:
+                    # For older data with no jyseps2_1 or jyseps1_2 in the
+                    # dataset, probably do not need to handle double null data
+                    # squashed with upper target points.
+                    is_squashed_doublenull = False
             elif ny_file == ny + 2 * myg:
                 # Older squashed file from double-null grid but containing only lower
                 # target boundary cells.
