@@ -98,7 +98,10 @@ class TestBoutDataArrayMethods:
             pytest.param(9, marks=pytest.mark.long),
         ],
     )
-    def test_to_field_aligned(self, bout_xyt_example_files, nz):
+    @pytest.mark.parametrize(
+        "permute_dims", [False, pytest.param(True, marks=pytest.mark.long)]
+    )
+    def test_to_field_aligned(self, bout_xyt_example_files, nz, permute_dims):
         dataset_list = bout_xyt_example_files(
             None, lengths=(3, 3, 4, nz), nxpe=1, nype=1, nt=1
         )
@@ -126,8 +129,15 @@ class TestBoutDataArrayMethods:
                         n[t, x, y, z] = 1000.0 * t + 100.0 * x + 10.0 * y + z
 
         n.attrs["direction_y"] = "Standard"
+
+        if permute_dims:
+            n = n.transpose("t", "zeta", "x", "theta").compute()
+
         n_al = n.bout.to_field_aligned()
 
+        if permute_dims:
+            n_al = n_al.transpose("t", "x", "theta", "zeta").compute()
+
         assert n_al.direction_y == "Aligned"
 
         for t in range(ds.sizes["t"]):
@@ -195,7 +205,10 @@ class TestBoutDataArrayMethods:
                     atol=0.0,
                 )  # noqa: E501
 
-    def test_to_field_aligned_dask(self, bout_xyt_example_files):
+    @pytest.mark.parametrize(
+        "permute_dims", [False, pytest.param(True, marks=pytest.mark.long)]
+    )
+    def test_to_field_aligned_dask(self, bout_xyt_example_files, permute_dims):
 
         nz = 6
 
@@ -231,8 +244,15 @@ class TestBoutDataArrayMethods:
         assert isinstance(n.data, dask.array.Array)
 
         n.attrs["direction_y"] = "Standard"
+
+        if permute_dims:
+            n = n.transpose("t", "zeta", "x", "theta").compute()
+
         n_al = n.bout.to_field_aligned()
 
+        if permute_dims:
+            n_al = n_al.transpose("t", "x", "theta", "zeta").compute()
+
         assert n_al.direction_y == "Aligned"
 
         for t in range(ds.sizes["t"]):
@@ -309,7 +329,10 @@ class TestBoutDataArrayMethods:
             pytest.param(9, marks=pytest.mark.long),
         ],
     )
-    def test_from_field_aligned(self, bout_xyt_example_files, nz):
+    @pytest.mark.parametrize(
+        "permute_dims", [False, pytest.param(True, marks=pytest.mark.long)]
+    )
+    def test_from_field_aligned(self, bout_xyt_example_files, nz, permute_dims):
         dataset_list = bout_xyt_example_files(
             None, lengths=(3, 3, 4, nz), nxpe=1, nype=1, nt=1
         )
@@ -337,8 +360,15 @@ class TestBoutDataArrayMethods:
                         n[t, x, y, z] = 1000.0 * t + 100.0 * x + 10.0 * y + z
 
         n.attrs["direction_y"] = "Aligned"
+
+        if permute_dims:
+            n = n.transpose("t", "zeta", "x", "theta").compute()
+
         n_nal = n.bout.from_field_aligned()
 
+        if permute_dims:
+            n_nal = n_nal.transpose("t", "x", "theta", "zeta").compute()
+
         assert n_nal.direction_y == "Standard"
 
         for t in range(ds.sizes["t"]):
@@ -407,7 +437,12 @@ class TestBoutDataArrayMethods:
                 )  # noqa: E501
 
     @pytest.mark.parametrize("stag_location", ["CELL_XLOW", "CELL_YLOW", "CELL_ZLOW"])
-    def test_to_field_aligned_staggered(self, bout_xyt_example_files, stag_location):
+    @pytest.mark.parametrize(
+        "permute_dims", [False, pytest.param(True, marks=pytest.mark.long)]
+    )
+    def test_to_field_aligned_staggered(
+        self, bout_xyt_example_files, stag_location, permute_dims
+    ):
         dataset_list = bout_xyt_example_files(
             None, lengths=(3, 3, 4, 8), nxpe=1, nype=1, nt=1
         )
@@ -434,8 +469,14 @@ class TestBoutDataArrayMethods:
                     for z in range(ds.sizes["zeta"]):
                         n[t, x, y, z] = 1000.0 * t + 100.0 * x + 10.0 * y + z
 
+        if permute_dims:
+            n = n.transpose("t", "zeta", "x", "theta").compute()
+
         n_al = n.bout.to_field_aligned().copy(deep=True)
 
+        if permute_dims:
+            n_al = n_al.transpose("t", "x", "theta", "zeta").compute()
+
         assert n_al.direction_y == "Aligned"
 
         # make 'n' staggered
@@ -459,7 +500,12 @@ class TestBoutDataArrayMethods:
         npt.assert_equal(n_stag_al.values, n_al.values)
 
     @pytest.mark.parametrize("stag_location", ["CELL_XLOW", "CELL_YLOW", "CELL_ZLOW"])
-    def test_from_field_aligned_staggered(self, bout_xyt_example_files, stag_location):
+    @pytest.mark.parametrize(
+        "permute_dims", [False, pytest.param(True, marks=pytest.mark.long)]
+    )
+    def test_from_field_aligned_staggered(
+        self, bout_xyt_example_files, stag_location, permute_dims
+    ):
         dataset_list = bout_xyt_example_files(
             None, lengths=(3, 3, 4, 8), nxpe=1, nype=1, nt=1
         )
@@ -488,8 +534,14 @@ class TestBoutDataArrayMethods:
         n.attrs["direction_y"] = "Aligned"
         ds["T"].attrs["direction_y"] = "Aligned"
 
+        if permute_dims:
+            n = n.transpose("t", "zeta", "x", "theta").compute()
+
         n_nal = n.bout.from_field_aligned().copy(deep=True)
 
+        if permute_dims:
+            n_nal = n_nal.transpose("t", "x", "theta", "zeta").compute()
+
         assert n_nal.direction_y == "Standard"
 
         # make 'n' staggered
@@ -550,7 +602,7 @@ class TestBoutDataArrayMethods:
 
         def f(t):
             t = np.sin(t)
-            return t ** 3 - t ** 2 + t - 1.0
+            return t**3 - t**2 + t - 1.0
 
         n.data = f(theta).broadcast_like(n)
 
@@ -612,7 +664,7 @@ class TestBoutDataArrayMethods:
 
         def f(t):
             t = np.sin(t)
-            return t ** 3 - t ** 2 + t - 1.0
+            return t**3 - t**2 + t - 1.0
 
         n.data = f(theta).broadcast_like(n)
 
@@ -660,7 +712,7 @@ class TestBoutDataArrayMethods:
 
         def f(t):
             t = np.sin(t)
-            return t ** 3 - t ** 2 + t - 1.0
+            return t**3 - t**2 + t - 1.0
 
         n.data = f(theta).broadcast_like(n)
 
@@ -709,7 +761,7 @@ class TestBoutDataArrayMethods:
 
         def f(t):
             t = np.sin(3.0 * t)
-            return t ** 3 - t ** 2 + t - 1.0
+            return t**3 - t**2 + t - 1.0
 
         n.data = f(theta).broadcast_like(n)
 
@@ -782,7 +834,7 @@ class TestBoutDataArrayMethods:
 
         def f_y(t):
             t = np.sin(3.0 * t)
-            return t ** 3 - t ** 2 + t - 1.0
+            return t**3 - t**2 + t - 1.0
 
         f = f_y(theta) * (x + 1.0)
 
@@ -834,7 +886,7 @@ class TestBoutDataArrayMethods:
 
         def f_y(t):
             t = np.sin(t)
-            return t ** 3 - t ** 2 + t - 1.0
+            return t**3 - t**2 + t - 1.0
 
         f = f_y(theta) * (x + 1.0)
 
@@ -902,6 +954,85 @@ class TestBoutDataArrayMethods:
 
         xrt.assert_identical(n_highres_truncated, n_highres.isel(zeta=points_list))
 
+    def test_interpolate_to_cartesian(self, bout_xyt_example_files):
+        dataset_list = bout_xyt_example_files(
+            None, lengths=(2, 16, 17, 18), nxpe=1, nype=1, nt=1
+        )
+        with pytest.warns(UserWarning):
+            ds = open_boutdataset(
+                datapath=dataset_list, inputfilepath=None, keep_xboundaries=False
+            )
+
+        ds["psixy"] = ds["g11"].copy(deep=True)
+        ds["Rxy"] = ds["g11"].copy(deep=True)
+        ds["Zxy"] = ds["g11"].copy(deep=True)
+
+        r = np.linspace(1.0, 2.0, ds.metadata["nx"])
+        theta = np.linspace(0.0, 2.0 * np.pi, ds.metadata["ny"])
+        R = r[:, np.newaxis] * np.cos(theta[np.newaxis, :])
+        Z = r[:, np.newaxis] * np.sin(theta[np.newaxis, :])
+        ds["Rxy"].values[:] = R
+        ds["Zxy"].values[:] = Z
+
+        ds = apply_geometry(ds, "toroidal")
+
+        da = ds["n"]
+        da.values[:] = 1.0
+
+        nX = 30
+        nY = 30
+        nZ = 10
+        da_cartesian = da.bout.interpolate_to_cartesian(nX, nY, nZ)
+
+        # Check a point inside the original grid
+        npt.assert_allclose(
+            da_cartesian.isel(t=0, X=round(nX * 4 / 5), Y=nY // 2, Z=nZ // 2).item(),
+            1.0,
+            rtol=1.0e-15,
+            atol=1.0e-15,
+        )
+        # Check a point outside the original grid
+        assert np.isnan(da_cartesian.isel(t=0, X=0, Y=0, Z=0).item())
+        # Check output is float32
+        assert da_cartesian.dtype == np.float32
+
+    def test_add_cartesian_coordinates(self, bout_xyt_example_files):
+        dataset_list = bout_xyt_example_files(None, nxpe=1, nype=1, nt=1)
+        with pytest.warns(UserWarning):
+            ds = open_boutdataset(
+                datapath=dataset_list, inputfilepath=None, keep_xboundaries=False
+            )
+
+        ds["psixy"] = ds["g11"].copy(deep=True)
+        ds["Rxy"] = ds["g11"].copy(deep=True)
+        ds["Zxy"] = ds["g11"].copy(deep=True)
+
+        r = np.linspace(1.0, 2.0, ds.metadata["nx"])
+        theta = np.linspace(0.0, 2.0 * np.pi, ds.metadata["ny"])
+        R = r[:, np.newaxis] * np.cos(theta[np.newaxis, :])
+        Z = r[:, np.newaxis] * np.sin(theta[np.newaxis, :])
+        ds["Rxy"].values[:] = R
+        ds["Zxy"].values[:] = Z
+
+        ds = apply_geometry(ds, "toroidal")
+
+        zeta = ds["zeta"].values
+
+        da = ds["n"].bout.add_cartesian_coordinates()
+
+        npt.assert_allclose(
+            da["X_cartesian"],
+            R[:, :, np.newaxis] * np.cos(zeta[np.newaxis, np.newaxis, :]),
+        )
+        npt.assert_allclose(
+            da["Y_cartesian"],
+            R[:, :, np.newaxis] * np.sin(zeta[np.newaxis, np.newaxis, :]),
+        )
+        npt.assert_allclose(
+            da["Z_cartesian"],
+            Z[:, :, np.newaxis] * np.ones(ds.metadata["nz"])[np.newaxis, np.newaxis, :],
+        )
+
     def test_ddx(self, bout_xyt_example_files):
 
         nx = 64
@@ -998,3 +1129,27 @@ class TestBoutDataArrayMethods:
         npt.assert_allclose(
             n.bout.ddz().values, expected.values, rtol=1.0e-2, atol=1.0e-13
         )
+
+    def test_derivatives_doublenull(self, bout_xyt_example_files):
+        # Check function does not error on double-null topology
+        dataset_list, grid_ds = bout_xyt_example_files(
+            None,
+            lengths=(2, 3, 4, 3),
+            nxpe=1,
+            nype=6,
+            nt=1,
+            grid="grid",
+            guards={"x": 2, "y": 2},
+            topology="connected-double-null",
+        )
+
+        ds = open_boutdataset(
+            datapath=dataset_list,
+            gridfilepath=grid_ds,
+            geometry="toroidal",
+            keep_yboundaries=True,
+        )
+
+        test_ddx = ds["n"].bout.ddx()
+        test_ddy = ds["n"].bout.ddy()
+        test_ddz = ds["n"].bout.ddz()
