@@ -1,5 +1,10 @@
+from collections import namedtuple
+from copy import deepcopy
+import inspect
 from pathlib import Path
 import re
+from functools import reduce
+import operator
 
 import pytest
 
@@ -23,57 +28,71 @@ from xbout.load import (
     _BOUT_TIME_DEPENDENT_META_VARS,
 )
 from xbout.utils import _separate_metadata
+from xbout.tests.utils_for_tests import _get_kwargs
 
 
-def test_check_extensions(tmpdir):
-    files_dir = tmpdir.mkdir("data")
-    example_nc_file = files_dir.join("example.nc")
-    example_nc_file.write("content_nc")
+def test_check_extensions(tmp_path):
+    files_dir = tmp_path.joinpath("data")
+    files_dir.mkdir()
+    example_nc_file = files_dir.joinpath("example.nc")
+    example_nc_file.write_text("content_nc")
 
-    filetype = _check_filetype(Path(str(example_nc_file)))
+    filetype = _check_filetype(example_nc_file)
     assert filetype == "netcdf4"
 
-    example_hdf5_file = files_dir.join("example.h5netcdf")
-    example_hdf5_file.write("content_hdf5")
+    example_hdf5_file = files_dir.joinpath("example.h5netcdf")
+    example_hdf5_file.write_text("content_hdf5")
 
-    filetype = _check_filetype(Path(str(example_hdf5_file)))
+    filetype = _check_filetype(example_hdf5_file)
     assert filetype == "h5netcdf"
 
-    example_invalid_file = files_dir.join("example.txt")
-    example_hdf5_file.write("content_txt")
+    example_invalid_file = files_dir.joinpath("example.txt")
+    example_hdf5_file.write_text("content_txt")
     with pytest.raises(IOError):
-        filetype = _check_filetype(Path(str(example_invalid_file)))
+        filetype = _check_filetype(example_invalid_file)
+
+
+def test_set_fci_coords(create_example_grid_file_fci, create_example_files_fci):
+    grid = create_example_grid_file_fci
+    data = create_example_files_fci
+
+    ds = open_boutdataset(data, gridfilepath=grid, geometry="fci")
+    assert "R" in ds
+    assert "Z" in ds
 
 
 class TestPathHandling:
-    def test_glob_expansion_single(self, tmpdir):
-        files_dir = tmpdir.mkdir("data")
-        example_file = files_dir.join("example.0.nc")
-        example_file.write("content")
+    def test_glob_expansion_single(self, tmp_path):
+        files_dir = tmp_path.joinpath("data")
+        files_dir.mkdir()
+        example_file = files_dir.joinpath("example.0.nc")
+        example_file.write_text("content")
 
-        path = Path(str(example_file))
+        path = example_file
         filepaths = _expand_wildcards(path)
-        assert filepaths[0] == Path(str(example_file))
+        assert filepaths[0] == example_file
 
-        path = Path(str(files_dir.join("example.*.nc")))
+        path = files_dir.joinpath("example.*.nc")
         filepaths = _expand_wildcards(path)
-        assert filepaths[0] == Path(str(example_file))
+        assert filepaths[0] == example_file
 
     @pytest.mark.parametrize(
         "ii, jj", [(1, 1), (1, 4), (3, 1), (5, 3), (12, 1), (1, 12), (121, 2), (3, 111)]
     )
-    def test_glob_expansion_both(self, tmpdir, ii, jj):
-        files_dir = tmpdir.mkdir("data")
+    def test_glob_expansion_both(self, tmp_path, ii, jj):
+        files_dir = tmp_path.joinpath("data")
+        files_dir.mkdir()
         filepaths = []
         for i in range(ii):
-            example_run_dir = files_dir.mkdir("run" + str(i))
+            example_run_dir = files_dir.joinpath("run" + str(i))
+            example_run_dir.mkdir()
             for j in range(jj):
-                example_file = example_run_dir.join("example." + str(j) + ".nc")
-                example_file.write("content")
-                filepaths.append(Path(str(example_file)))
+                example_file = example_run_dir.joinpath("example." + str(j) + ".nc")
+                example_file.write_text("content")
+                filepaths.append(example_file)
         expected_filepaths = natsorted(filepaths, key=lambda filepath: str(filepath))
 
-        path = Path(str(files_dir.join("run*/example.*.nc")))
+        path = files_dir.joinpath("run*/example.*.nc")
         actual_filepaths = _expand_wildcards(path)
 
         assert actual_filepaths == expected_filepaths
@@ -81,27 +100,30 @@ class TestPathHandling:
     @pytest.mark.parametrize(
         "ii, jj", [(1, 1), (1, 4), (3, 1), (5, 3), (1, 12), (3, 111)]
     )
-    def test_glob_expansion_brackets(self, tmpdir, ii, jj):
-        files_dir = tmpdir.mkdir("data")
+    def test_glob_expansion_brackets(self, tmp_path, ii, jj):
+        files_dir = tmp_path.joinpath("data")
+        files_dir.mkdir()
         filepaths = []
         for i in range(ii):
-            example_run_dir = files_dir.mkdir("run" + str(i))
+            example_run_dir = files_dir.joinpath("run" + str(i))
+            example_run_dir.mkdir()
             for j in range(jj):
-                example_file = example_run_dir.join("example." + str(j) + ".nc")
-                example_file.write("content")
-                filepaths.append(Path(str(example_file)))
+                example_file = example_run_dir.joinpath("example." + str(j) + ".nc")
+                example_file.write_text("content")
+                filepaths.append(example_file)
         expected_filepaths = natsorted(filepaths, key=lambda filepath: str(filepath))
 
-        path = Path(str(files_dir.join("run[1-9]/example.*.nc")))
+        path = files_dir.joinpath("run[1-9]/example.*.nc")
         actual_filepaths = _expand_wildcards(path)
 
         assert actual_filepaths == expected_filepaths[jj:]
 
-    def test_no_files(self, tmpdir):
-        files_dir = tmpdir.mkdir("data")
+    def test_no_files(self, tmp_path):
+        files_dir = tmp_path.joinpath("data")
+        files_dir.mkdir()
 
         with pytest.raises(IOError):
-            path = Path(str(files_dir.join("run*/example.*.nc")))
+            path = files_dir.joinpath("run*/example.*.nc")
             actual_filepaths = _expand_filepaths(path)
 
 
@@ -242,19 +264,22 @@ class TestArrange:
         assert actual_concat_dims == ["t", "y", "x"]
 
 
-@pytest.fixture()
-def bout_xyt_example_files(tmpdir_factory):
+@pytest.fixture(scope="session")
+def bout_xyt_example_files(tmp_path_factory):
     return _bout_xyt_example_files
 
 
+_bout_xyt_example_files_cache = {}
+
+
 def _bout_xyt_example_files(
-    tmpdir_factory,
+    tmp_path_factory,
     prefix="BOUT.dmp",
     lengths=(6, 2, 4, 7),
     nxpe=4,
     nype=2,
     nt=1,
-    guards={},
+    guards=None,
     syn_data_type="random",
     grid=None,
     squashed=False,
@@ -271,6 +296,16 @@ def _bout_xyt_example_files(
     containing them, deleting the temporary directory once that test is done (if
     write_to_disk=True).
     """
+    call_args = _get_kwargs(ignore="tmp_path_factory")
+
+    try:
+        # Has been called with the same signature before, just return the cached result
+        return deepcopy(_bout_xyt_example_files_cache[call_args])
+    except KeyError:
+        pass
+
+    if guards is None:
+        guards = {}
 
     mxg = guards.get("x", 0)
     myg = guards.get("y", 0)
@@ -326,23 +361,24 @@ def _bout_xyt_example_files(
 
     if not write_to_disk:
         if grid is None:
-            return ds_list
+            _bout_xyt_example_files_cache[call_args] = ds_list
+            return deepcopy(ds_list)
         else:
-            return ds_list, grid_ds
-    elif tmpdir_factory is None:
-        raise ValueError("tmpdir_factory required when write_to_disk=True")
+            _bout_xyt_example_files_cache[call_args] = ds_list, grid_ds
+            return deepcopy((ds_list, grid_ds))
+        raise ValueError("tmp_path_factory required when write_to_disk=True")
 
-    save_dir = tmpdir_factory.mktemp("data")
+    save_dir = tmp_path_factory.mktemp("data")
 
     for ds, file_name in zip(ds_list, file_list):
-        ds.to_netcdf(str(save_dir.join(str(file_name))))
+        ds.to_netcdf(save_dir.joinpath(file_name))
 
     if grid is not None:
-        grid_ds.to_netcdf(str(save_dir.join(grid + ".nc")))
+        grid_ds.to_netcdf(save_dir.joinpath(grid + ".nc"))
 
     # Return a glob-like path to all files created, which has all file numbers replaced
     # with a single asterix
-    path = str(save_dir.join(str(file_list[-1])))
+    path = str(save_dir.joinpath(file_list[-1]))
 
     count = 1
     if nt > 1:
@@ -350,7 +386,8 @@ def _bout_xyt_example_files(
     # We have to reverse the path before limiting the number of numbers replaced so that the
     # tests don't get confused by pytest's persistent temporary directories (which are also designated
     # by different numbers)
-    glob_pattern = (re.sub(r"\d+", "*", path[::-1], count=count))[::-1]
+    glob_pattern = Path((re.sub(r"\d+", "*", path[::-1], count=count))[::-1])
+    _bout_xyt_example_files_cache[call_args] = glob_pattern
     return glob_pattern
 
 
@@ -410,6 +447,9 @@ def create_bout_ds_list(
     return ds_list, file_list
 
 
+_create_bout_ds_cache = {}
+
+
 def create_bout_ds(
     syn_data_type="random",
     lengths=(6, 2, 4, 7),
@@ -424,6 +464,13 @@ def create_bout_ds(
     bout_v5=False,
     metric_3D=False,
 ):
+    call_args = _get_kwargs()
+
+    try:
+        # Has been called with the same signature before, just return the cached result
+        return deepcopy(_create_bout_ds_cache[call_args])
+    except KeyError:
+        pass
 
     if metric_3D and not bout_v5:
         raise ValueError("3D metric requires BOUT++ v5")
@@ -482,10 +529,16 @@ def create_bout_ds(
 
     T = DataArray(data, dims=["t", "x", "y", "z"])
     n = DataArray(data, dims=["t", "x", "y", "z"])
+    S = DataArray(data[:, :, :, 0], dims=["t", "x", "y"])
     for v in [n, T]:
         v.attrs["direction_y"] = "Standard"
         v.attrs["cell_location"] = "CELL_CENTRE"
-    ds = Dataset({"n": n, "T": T})
+        v.attrs["direction_z"] = "Standard"
+    for v in [S]:
+        v.attrs["direction_y"] = "Standard"
+        v.attrs["cell_location"] = "CELL_CENTRE"
+        v.attrs["direction_z"] = "Average"
+    ds = Dataset({"n": n, "T": T, "S": S})
 
     # BOUT_VERSION needed to deal with backwards incompatible changes:
     #
@@ -660,17 +713,30 @@ def create_bout_ds(
     else:
         ds["dz"] = 2.0 * np.pi / nz
 
-    ds["iteration"] = t_length
+    ds["iteration"] = t_length - 1
+    ds["hist_hi"] = t_length - 1
     ds["t_array"] = DataArray(np.arange(t_length, dtype=float) * 10.0, dims="t")
+    ds["tt"] = ds["t_array"][-1]
 
     # xarray adds this encoding when opening a file. Emulate here as it may be used to
     # get the file number
     ds.encoding["source"] = f"BOUT.dmp.{num}.nc"
 
-    return ds
+    _create_bout_ds_cache[call_args] = ds
+    return deepcopy(ds)
+
+
+_create_bout_grid_ds_cache = {}
 
 
 def create_bout_grid_ds(xsize=2, ysize=4, guards={}, topology="core", ny_inner=0):
+    call_args = _get_kwargs()
+
+    try:
+        # Has been called with the same signature before, just return the cached result
+        return deepcopy(_create_bout_grid_ds_cache[call_args])
+    except KeyError:
+        pass
 
     # Set the shape of the data in this dataset
     mxg = guards.get("x", 0)
@@ -708,7 +774,8 @@ def create_bout_grid_ds(xsize=2, ysize=4, guards={}, topology="core", ny_inner=0
         }
     )
 
-    return ds
+    _create_bout_grid_ds_cache[call_args] = ds
+    return deepcopy(ds)
 
 
 # Note, MYPE, PE_XIND and PE_YIND not included, since they are different for each
@@ -728,6 +795,8 @@ METADATA_VARS = [
     "MXSUB",
     "MYSUB",
     "MZSUB",
+    "hist_hi",
+    "iteration",
     "ixseps1",
     "ixseps2",
     "jyseps1_1",
@@ -735,6 +804,7 @@ METADATA_VARS = [
     "jyseps2_1",
     "jyseps2_2",
     "ny_inner",
+    "tt",
     "zperiod",
     "ZMIN",
     "ZMAX",
@@ -759,9 +829,9 @@ class TestStripMetadata:
 
 # TODO also test loading multiple files which have guard cells
 class TestOpen:
-    def test_single_file(self, tmpdir_factory, bout_xyt_example_files):
+    def test_single_file(self, tmp_path_factory, bout_xyt_example_files):
         path = bout_xyt_example_files(
-            tmpdir_factory, nxpe=1, nype=1, nt=1, write_to_disk=True
+            tmp_path_factory, nxpe=1, nype=1, nt=1, write_to_disk=True
         )
         with pytest.warns(UserWarning):
             actual = open_boutdataset(datapath=path, keep_xboundaries=False)
@@ -785,9 +855,9 @@ class TestOpen:
             fake = open_boutdataset(datapath=fake_ds_list, keep_xboundaries=False)
         xrt.assert_identical(actual, fake)
 
-    def test_squashed_file(self, tmpdir_factory, bout_xyt_example_files):
+    def test_squashed_file(self, tmp_path_factory, bout_xyt_example_files):
         path = bout_xyt_example_files(
-            tmpdir_factory, nxpe=4, nype=3, nt=1, squashed=True, write_to_disk=True
+            tmp_path_factory, nxpe=4, nype=3, nt=1, squashed=True, write_to_disk=True
         )
         with pytest.warns(UserWarning):
             actual = open_boutdataset(datapath=path, keep_xboundaries=False)
@@ -818,10 +888,14 @@ class TestOpen:
         "keep_yboundaries", [False, pytest.param(True, marks=pytest.mark.long)]
     )
     def test_squashed_doublenull(
-        self, tmpdir_factory, bout_xyt_example_files, keep_xboundaries, keep_yboundaries
+        self,
+        tmp_path_factory,
+        bout_xyt_example_files,
+        keep_xboundaries,
+        keep_yboundaries,
     ):
         path = bout_xyt_example_files(
-            tmpdir_factory,
+            tmp_path_factory,
             nxpe=4,
             nype=6,
             nt=1,
@@ -852,10 +926,14 @@ class TestOpen:
         "keep_yboundaries", [False, pytest.param(True, marks=pytest.mark.long)]
     )
     def test_squashed_doublenull_file(
-        self, tmpdir_factory, bout_xyt_example_files, keep_xboundaries, keep_yboundaries
+        self,
+        tmp_path_factory,
+        bout_xyt_example_files,
+        keep_xboundaries,
+        keep_yboundaries,
     ):
         path = bout_xyt_example_files(
-            tmpdir_factory,
+            tmp_path_factory,
             nxpe=4,
             nype=6,
             nt=1,
@@ -880,9 +958,9 @@ class TestOpen:
         assert ds.sizes["y"] == 32 if keep_yboundaries else 24
         assert ds.sizes["z"] == 7
 
-    def test_combine_along_x(self, tmpdir_factory, bout_xyt_example_files):
+    def test_combine_along_x(self, tmp_path_factory, bout_xyt_example_files):
         path = bout_xyt_example_files(
-            tmpdir_factory,
+            tmp_path_factory,
             nxpe=4,
             nype=1,
             nt=1,
@@ -916,9 +994,9 @@ class TestOpen:
             fake = open_boutdataset(datapath=fake_ds_list, keep_xboundaries=False)
         xrt.assert_identical(actual, fake)
 
-    def test_combine_along_y(self, tmpdir_factory, bout_xyt_example_files):
+    def test_combine_along_y(self, tmp_path_factory, bout_xyt_example_files):
         path = bout_xyt_example_files(
-            tmpdir_factory,
+            tmp_path_factory,
             nxpe=1,
             nype=3,
             nt=1,
@@ -959,10 +1037,10 @@ class TestOpen:
     )
     @pytest.mark.parametrize("lengths", [(6, 2, 4, 7), (6, 2, 4, 1)])
     def test_combine_along_xy(
-        self, tmpdir_factory, bout_xyt_example_files, bout_v5, metric_3D, lengths
+        self, tmp_path_factory, bout_xyt_example_files, bout_v5, metric_3D, lengths
     ):
         path = bout_xyt_example_files(
-            tmpdir_factory,
+            tmp_path_factory,
             nxpe=4,
             nype=3,
             nt=1,
@@ -1020,10 +1098,10 @@ class TestOpen:
             fake = open_boutdataset(datapath=fake_ds_list, keep_xboundaries=False)
         xrt.assert_identical(actual, fake)
 
-    def test_toroidal(self, tmpdir_factory, bout_xyt_example_files):
+    def test_toroidal(self, tmp_path_factory, bout_xyt_example_files):
         # actually write these to disk to test the loading fully
         path = bout_xyt_example_files(
-            tmpdir_factory,
+            tmp_path_factory,
             nxpe=3,
             nype=3,
             nt=1,
@@ -1034,12 +1112,12 @@ class TestOpen:
         actual = open_boutdataset(
             datapath=path,
             geometry="toroidal",
-            gridfilepath=Path(path).parent.joinpath("grid.nc"),
+            gridfilepath=path.parent.joinpath("grid.nc"),
         )
 
         # check dataset can be saved
-        save_dir = tmpdir_factory.mktemp("data")
-        actual.bout.save(str(save_dir.join("boutdata.nc")))
+        save_dir = tmp_path_factory.mktemp("data")
+        actual.bout.save(save_dir.joinpath("boutdata.nc"))
 
         # check creation without writing to disk gives identical result
         fake_ds_list, fake_grid_ds = bout_xyt_example_files(
@@ -1055,9 +1133,9 @@ class TestOpen:
         )
         xrt.assert_identical(actual, fake)
 
-    def test_salpha(self, tmpdir_factory, bout_xyt_example_files):
+    def test_salpha(self, tmp_path_factory, bout_xyt_example_files):
         path = bout_xyt_example_files(
-            tmpdir_factory,
+            tmp_path_factory,
             nxpe=3,
             nype=3,
             nt=1,
@@ -1068,12 +1146,12 @@ class TestOpen:
         actual = open_boutdataset(
             datapath=path,
             geometry="s-alpha",
-            gridfilepath=Path(path).parent.joinpath("grid.nc"),
+            gridfilepath=path.parent.joinpath("grid.nc"),
         )
 
         # check dataset can be saved
-        save_dir = tmpdir_factory.mktemp("data")
-        actual.bout.save(str(save_dir.join("boutdata.nc")))
+        save_dir = tmp_path_factory.mktemp("data")
+        actual.bout.save(save_dir.joinpath("boutdata.nc"))
 
         # check creation without writing to disk gives identical result
         fake_ds_list, fake_grid_ds = bout_xyt_example_files(
@@ -1084,9 +1162,9 @@ class TestOpen:
         )
         xrt.assert_identical(actual, fake)
 
-    def test_drop_vars(self, tmpdir_factory, bout_xyt_example_files):
+    def test_drop_vars(self, tmp_path_factory, bout_xyt_example_files):
         datapath = bout_xyt_example_files(
-            tmpdir_factory,
+            tmp_path_factory,
             nxpe=4,
             nype=1,
             nt=1,
@@ -1105,6 +1183,14 @@ class TestOpen:
     def test_combine_along_tx(self):
         ...
 
+    def test_restarts(self):
+        datapath = Path(__file__).parent.joinpath(
+            "data", "restart", "BOUT.restart.*.nc"
+        )
+        ds = open_boutdataset(datapath, keep_xboundaries=True, keep_yboundaries=True)
+
+        assert "T" in ds
+
 
 _test_processor_layouts_list = [
     # No parallelization
@@ -1175,18 +1261,23 @@ _test_processor_layouts_doublenull_list = [
 
 
 class TestTrim:
-    def test_no_trim(self):
+    @pytest.mark.parametrize("is_restart", [False, True])
+    def test_no_trim(self, is_restart):
         ds = create_test_data(0)
         # Manually add filename - encoding normally added by xr.open_dataset
         ds.encoding["source"] = "folder0/BOUT.dmp.0.nc"
-        actual = _trim(ds, guards={}, keep_boundaries={}, nxpe=1, nype=1)
+        actual = _trim(
+            ds, guards={}, keep_boundaries={}, nxpe=1, nype=1, is_restart=is_restart
+        )
         xrt.assert_equal(actual, ds)
 
     def test_trim_guards(self):
         ds = create_test_data(0)
         # Manually add filename - encoding normally added by xr.open_dataset
         ds.encoding["source"] = "folder0/BOUT.dmp.0.nc"
-        actual = _trim(ds, guards={"time": 2}, keep_boundaries={}, nxpe=1, nype=1)
+        actual = _trim(
+            ds, guards={"time": 2}, keep_boundaries={}, nxpe=1, nype=1, is_restart=False
+        )
         selection = {"time": slice(2, -2)}
         expected = ds.isel(**selection)
         xrt.assert_equal(expected, actual)
@@ -1313,7 +1404,8 @@ class TestTrim:
         assert actual_lower_boundaries == lower_boundaries
         assert actual_upper_boundaries == upper_boundaries
 
-    def test_keep_xboundaries(self):
+    @pytest.mark.parametrize("is_restart", [False, True])
+    def test_keep_xboundaries(self, is_restart):
         ds = create_test_data(0)
         ds = ds.rename({"dim2": "x"})
 
@@ -1323,11 +1415,19 @@ class TestTrim:
         ds["jyseps2_1"] = 8
         ds["jyseps1_2"] = 8
 
-        actual = _trim(ds, guards={"x": 2}, keep_boundaries={"x": True}, nxpe=1, nype=1)
+        actual = _trim(
+            ds,
+            guards={"x": 2},
+            keep_boundaries={"x": True},
+            nxpe=1,
+            nype=1,
+            is_restart=is_restart,
+        )
         expected = ds  # Should be unchanged
         xrt.assert_equal(expected, actual)
 
-    def test_keep_yboundaries(self):
+    @pytest.mark.parametrize("is_restart", [False, True])
+    def test_keep_yboundaries(self, is_restart):
         ds = create_test_data(0)
         ds = ds.rename({"dim2": "y"})
 
@@ -1337,7 +1437,14 @@ class TestTrim:
         ds["jyseps2_1"] = 8
         ds["jyseps1_2"] = 8
 
-        actual = _trim(ds, guards={"y": 2}, keep_boundaries={"y": True}, nxpe=1, nype=1)
+        actual = _trim(
+            ds,
+            guards={"y": 2},
+            keep_boundaries={"y": True},
+            nxpe=1,
+            nype=1,
+            is_restart=is_restart,
+        )
         expected = ds  # Should be unchanged
         xrt.assert_equal(expected, actual)
 
@@ -1345,7 +1452,10 @@ class TestTrim:
         "filenum, lower, upper",
         [(0, True, False), (1, False, True), (2, True, False), (3, False, True)],
     )
-    def test_keep_yboundaries_doublenull_by_filenum(self, filenum, lower, upper):
+    @pytest.mark.parametrize("is_restart", [False, True])
+    def test_keep_yboundaries_doublenull_by_filenum(
+        self, filenum, lower, upper, is_restart
+    ):
         ds = create_test_data(0)
         ds = ds.rename({"dim2": "y"})
 
@@ -1357,7 +1467,14 @@ class TestTrim:
         ds["ny_inner"] = 8
         ds["MYSUB"] = 4
 
-        actual = _trim(ds, guards={"y": 2}, keep_boundaries={"y": True}, nxpe=1, nype=4)
+        actual = _trim(
+            ds,
+            guards={"y": 2},
+            keep_boundaries={"y": True},
+            nxpe=1,
+            nype=4,
+            is_restart=is_restart,
+        )
         expected = ds  # Should be unchanged
         if not lower:
             expected = expected.isel(y=slice(2, None, None))
@@ -1365,7 +1482,8 @@ class TestTrim:
             expected = expected.isel(y=slice(None, -2, None))
         xrt.assert_equal(expected, actual)
 
-    def test_trim_timing_info(self):
+    @pytest.mark.parametrize("is_restart", [False, True])
+    def test_trim_timing_info(self, is_restart):
         ds = create_test_data(0)
         from xbout.load import _BOUT_PER_PROC_VARIABLES
 
@@ -1375,7 +1493,60 @@ class TestTrim:
 
         for v in _BOUT_PER_PROC_VARIABLES:
             ds[v] = 42.0
-        ds = _trim(ds, guards={}, keep_boundaries={}, nxpe=1, nype=1)
+        ds = _trim(
+            ds, guards={}, keep_boundaries={}, nxpe=1, nype=1, is_restart=is_restart
+        )
 
         expected = create_test_data(0)
         xrt.assert_equal(ds, expected)
+
+
+fci_shape = (2, 2, 3, 4)
+fci_guards = (2, 2, 0)
+
+
+@pytest.fixture
+def create_example_grid_file_fci(tmp_path_factory):
+    """
+    Mocks up a FCI-like netCDF file, and return the temporary test
+    directory containing them.
+
+    Deletes the temporary directory once that test is done.
+    """
+
+    # Create grid dataset
+    shape = (fci_shape[1] + 2 * fci_guards[0], *fci_shape[2:])
+    arr = np.arange(reduce(operator.mul, shape, 1)).reshape(shape)
+    grid = DataArray(data=arr, name="R", dims=["x", "y", "z"]).to_dataset()
+    grid["Z"] = DataArray(np.random.random(shape), dims=["x", "y", "z"])
+    grid["dy"] = DataArray(np.ones(shape), dims=["x", "y", "z"])
+    grid = grid.set_coords(["dy"])
+
+    # Create temporary directory
+    save_dir = tmp_path_factory.mktemp("griddata")
+
+    # Save
+    filepath = save_dir.joinpath("fci.nc")
+    grid.to_netcdf(filepath, engine="netcdf4")
+
+    return filepath
+
+
+@pytest.fixture
+def create_example_files_fci(tmp_path_factory):
+
+    return _bout_xyt_example_files(
+        tmp_path_factory,
+        lengths=fci_shape,
+        nxpe=1,
+        nype=1,
+        # nt=1,
+        guards={a: b for a, b in zip("xyz", fci_guards)},
+        syn_data_type="random",
+        grid=None,
+        squashed=False,
+        # topology="core",
+        write_to_disk=False,
+        bout_v5=True,
+        metric_3D=True,
+    )
